# Code of Conduct

We are a community based on openness, as well as friendly and didactic discussions.

We aspire to treat everybody equally, and value their contributions.

Decisions are made based on technical merit and consensus.

Code is not the only way to help the project. Reviewing pull requests, answering questions to help others on issues, improving the documentation, organizing tutorials, and teaching are all priceless contributions.

We abide by the principles of openness, respect, and consideration of others of the Python Software Foundation: <https://www.python.org/psf/codeofconduct/>

## Low Quality and AI Generated Contributions Policy

Due to the burden put on maintainers, users submitting multiple low quality pull requests, or AI generated comments, reviews, issues, or pull requests, where the user does not show a good understanding of what they are posting, might be banned from the organization. Some examples of poor etiquette are:

- Opening a PR for issues which are not yet triaged and the "triage" label is not removed;
- Claiming to work on many issues at the same time;
- Claiming issues or opening pull requests where another person has already claimed it or where there's already a PR fixing the issue;
- Opening AI generated pull requests without understanding them;
- Leaving AI generated comments on issues and pull requests.

For more context, you can check out this blog post on [The Cost of AI in Open Source Maintenance](https://adrin.info/the-cost-of-ai-in-open-source-maintenance.html).

If this happens to you and you believe it's been a mistake, you can open an issue or reach out to the maintainers
